=======
Credits
=======

Development Lead
----------------

* James M. Irving <james.irving.phd@outlook.com>
* Michael V. Moravetz <moravetzmichael@gmail.com>

Contributors
------------

None yet. Why not be the first?
